/*
 * Sshtools - Java SSH2 API
 *
 * Copyright (C) 2002 Lee David Painter.
 *
 * Written by: 2002 Lee David Painter <lee@sshtools.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License
 * as published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.RollingFileAppender;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;

import com.sshtools.j2ssh.io.IOStreamConnector;
import com.sshtools.j2ssh.io.IOStreamConnectorState;

import com.sshtools.j2ssh.SshClient;
import com.sshtools.j2ssh.authentication.PasswordAuthenticationClient;
import com.sshtools.j2ssh.authentication.AuthenticationProtocolState;
import com.sshtools.j2ssh.session.SessionChannelClient;

import com.sshtools.j2ssh.configuration.SshConnectionProperties;

import com.sshtools.j2ssh.transport.ConsoleHostKeyVerification;

/**
 * Demonstrates a simple password connection to an SSH server.
 *
 * @author <A HREF="mailto:lee@sshtools.com">Lee David Painter</A>
 * @version $Id: PasswordConnect.java,v 1.4 2003/02/17 16:00:21 martianx Exp $
 *
 * @created 20 December 2002
 */
public class PasswordConnect {
    /**
     * The main program for the PasswordConnect class
     *
     * @param args The command line arguments
     */
    public static void main(String args[]) {
        try {
            RollingFileAppender log =
                new RollingFileAppender(new PatternLayout(), "ssh.log", true);
            log.setMaxFileSize("100KB");
            BasicConfigurator.configure(log);

            BufferedReader reader =
                new BufferedReader(new InputStreamReader(System.in));
            System.out.print("Connect to host? ");

            String hostname = reader.readLine();

            // Make a client connection
            SshClient ssh = new SshClient();
            SshConnectionProperties properties = new SshConnectionProperties();
            properties.setHost(hostname);

            // Connect to the host
            ssh.connect(properties, new ConsoleHostKeyVerification());

            // Create a password authentication instance
            PasswordAuthenticationClient pwd = new PasswordAuthenticationClient();

            // Get the users name
            System.out.print("Username? ");

 	    // Read the password
            String username = reader.readLine();
            pwd.setUsername(username);

            // Get the password
            System.out.print("Password? ");

            String password = reader.readLine();
            pwd.setPassword(password);

            // Try the authentication
            int result = ssh.authenticate(pwd);

            // Evaluate the result
            if (result==AuthenticationProtocolState.COMPLETE) {


                // The connection is authenticated we can now do some real work!
                SessionChannelClient session = ssh.openSessionChannel();


                if(session.executeCommand("set")) {

                  InputStream in = session.getInputStream();
                  OutputStream out = session.getOutputStream();

                  IOStreamConnector input =
                      new IOStreamConnector(System.in, session.getOutputStream());
                  IOStreamConnector output =
                      new IOStreamConnector(session.getInputStream(), System.out);
                  IOStreamConnector error =
                      new IOStreamConnector(session.getStderrInputStream(), System.out);

                  output.getState().waitForState(IOStreamConnectorState.CLOSED);
                }

                ssh.disconnect();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
