/*
 * Sshtools - Java SSH2 API
 *
 * Copyright (C) 2002 Lee David Painter.
 *
 * Written by: 2002 Lee David Painter <lee@sshtools.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License
 * as published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.RollingFileAppender;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;

import com.sshtools.j2ssh.io.IOStreamConnector;
import com.sshtools.j2ssh.io.IOStreamConnectorState;

import com.sshtools.j2ssh.sftp.*;

import com.sshtools.j2ssh.SshClient;
import com.sshtools.j2ssh.authentication.PasswordAuthenticationClient;
import com.sshtools.j2ssh.authentication.AuthenticationProtocolState;
import com.sshtools.j2ssh.session.SessionChannelClient;

import com.sshtools.j2ssh.io.UnsignedInteger64;
import com.sshtools.j2ssh.io.UnsignedInteger32;
import com.sshtools.j2ssh.io.ByteArrayWriter;

import java.util.Vector;

/**
 * Demonstrates a simple password connection to an SSH server.
 *
 * @author <A HREF="mailto:lee@sshtools.com">Lee David Painter</A>
 * @version $Id: SftpConnect.java,v 1.2 2003/02/17 16:00:15 martianx Exp $
 *
 * @created 20 December 2002
 */
public class SftpConnect {
    /**
     * The main program for the PasswordConnect class
     *
     * @param args The command line arguments
     */
    public static void main(String args[]) {
        try {

            BufferedReader reader =
                new BufferedReader(new InputStreamReader(System.in));
            System.out.print("Connect to host? ");

            String hostname = reader.readLine();

            // Make a client connection
            SshClient ssh = new SshClient();

            // Connect to the host
            ssh.connect(hostname);

            // Create a password authentication instance
            PasswordAuthenticationClient pwd = new PasswordAuthenticationClient();

            // Get the users name
            System.out.print("Username? ");

            String username = reader.readLine();
            pwd.setUsername(username);

            // Get the password
            System.out.print("Password? ");

            String password = reader.readLine();
            pwd.setPassword(password);

            // Try the authentication
            int result = ssh.authenticate(pwd);

            // Evaluate the result
            if (result==AuthenticationProtocolState.COMPLETE) {
                // The connection is authenticated we can now do some real work!
                SessionChannelClient session = ssh.openSessionChannel();
                SftpSubsystemClient sftp = new SftpSubsystemClient();
                session.startSubsystem(sftp);

                FileAttributes attrs = new FileAttributes();
                attrs.setPermissions("rwxrwxrwx");
                attrs.setPermissions(new UnsignedInteger32(
            attrs.getPermissions().intValue()
            | FileAttributes.S_IFREG));

                // Now try to write to a file without creating it!
                SftpFile file = sftp.openFile("cp.txt",
                                              SftpSubsystemClient.OPEN_CREATE
                                              | SftpSubsystemClient.OPEN_WRITE, attrs);

                /*FileAttributes attrs = file.getAttributes();
                attrs.setPermissions("rwxrwxrwx");
                sftp.setAttributes(file, attrs);*/

                SftpFileOutputStream out = new SftpFileOutputStream(file);
                String line = "All work and no play makes johnny a bad boy!\n";
                for(int i=0;i<100;i++)
                  out.write(line.getBytes());

                out.close();



                session.close();
                ssh.disconnect();

            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
                System.exit(0);
        }
    }
}
